@@ -9,10 +9,11 @@ package App::Git::Workflow::Command::BranchGrep;
 use strict;
 use warnings;
 use English qw/ -no_match_vars /;
+use Term::ANSIColor qw/colored/;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.99;
+our $VERSION  = 1.0.1;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -20,6 +21,7 @@ our %option;
 sub run {
     get_options(
         \%option,
+        'colour|color|c',
         'remote|r',
         'all|a',
         'insensitive|i',
@@ -31,11 +33,12 @@ sub run {
     push @options, '-a' if $option{all};
     my $grep = $option{insensitive} ? "(?i:$ARGV[0])" : $ARGV[0];
 
-    print join "\n",
-        sort {_sorter()}
-        grep { $option{v} ? !/$grep/ : /$grep/ }
-        $workflow->git->branch(@options);
-    print "\n";
+    for my $branch ( sort {_sorter()} grep { $option{v} ? !/$grep/ : /$grep/ } $workflow->git->branch(@options) ) {
+        if ( $option{colour} ) {
+            $branch =~ s/($grep)/colored ['red'], $1/egxms;
+        }
+        print "$branch\n";
+    }
 }
 
 sub _sorter {
@@ -57,7 +60,7 @@ git-branch-grep - grep for branch names
 
 =head1 VERSION
 
-This documentation refers to git-branch-grep version 0.99
+This documentation refers to git-branch-grep version 1.0.1
 
 =head1 SYNOPSIS
 
