@@ -9,10 +9,11 @@ package App::Git::Workflow::Command::TagGrep;
 use strict;
 use warnings;
 use English qw/ -no_match_vars /;
+use Term::ANSIColor qw/colored/;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.99;
+our $VERSION  = 1.0.1;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -20,14 +21,19 @@ our %option;
 sub run {
     get_options(
         \%option,
+        'colour|color|c',
         'insensitive|i',
     );
 
     $ARGV[0] ||= '';
     my $grep = $option{insensitive} ? "(?i:$ARGV[0])" : $ARGV[0];
 
-    print join "\n", sort {_sorter()} grep {/$grep/} $workflow->git->tag;
-    print "\n";
+    for my $tag ( sort {_sorter()} grep {/$grep/} $workflow->git->tag ) {
+        if ( $option{colour} ) {
+            $tag =~ s/($grep)/colored ['red'], $1 /egxms;
+        }
+        print "$tag\n";
+    }
 }
 
 sub _sorter {
@@ -49,7 +55,7 @@ git-tag-grep - grep tags
 
 =head1 VERSION
 
-This documentation refers to git-tag-grep version 0.99
+This documentation refers to git-tag-grep version 1.0.1
 
 =head1 SYNOPSIS
 
